/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {postForm} from 'frontend-js-web';

export default function propsTransformer({
	additionalProps: {editRedirectNotFoundEntriesURL},
	portletNamespace,
	...otherProps
}) {
	const ignoreSelectedRedirectNotFoundEntries = () => {
		const form = document.getElementById(`${portletNamespace}fm`);

		if (form) {
			postForm(form, {
				data: {
					deleteEntryIds: Liferay.Util.listCheckedExcept(
						form,
						`${portletNamespace}allRowIds`
					),
					ignored: true,
				},
				url: editRedirectNotFoundEntriesURL,
			});
		}
	};

	const unignoreSelectedRedirectNotFoundEntries = () => {
		const form = document.getElementById(`${portletNamespace}fm`);

		if (form) {
			postForm(form, {
				data: {
					deleteEntryIds: Liferay.Util.listCheckedExcept(
						form,
						`${portletNamespace}allRowIds`
					),
					ignored: false,
				},
				url: editRedirectNotFoundEntriesURL,
			});
		}
	};

	return {
		...otherProps,
		onActionButtonClick: (event, {item}) => {
			const action = item?.data?.action;

			if (action === 'ignoreSelectedRedirectNotFoundEntries') {
				ignoreSelectedRedirectNotFoundEntries();
			}
			else if (action === 'unignoreSelectedRedirectNotFoundEntries') {
				unignoreSelectedRedirectNotFoundEntries();
			}
		},
	};
}
