<%--
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */
--%>

<%@ include file="/init.jsp" %>

<%
StagingGroupHelper stagingGroupHelper = StagingGroupHelperUtil.getStagingGroupHelper();

boolean stagingGroup = stagingGroupHelper.isLocalStagingGroup(themeDisplay.getScopeGroup()) || stagingGroupHelper.isRemoteStagingGroup(themeDisplay.getScopeGroup());

RedirectDisplayContext redirectDisplayContext = new RedirectDisplayContext(request, liferayPortletRequest, liferayPortletResponse);

SearchContainer<RedirectEntry> redirectSearchContainer = redirectDisplayContext.searchContainer();

RedirectManagementToolbarDisplayContext redirectManagementToolbarDisplayContext = new RedirectManagementToolbarDisplayContext(request, liferayPortletRequest, liferayPortletResponse, redirectSearchContainer);
%>

<c:if test="<%= !stagingGroup %>">
	<clay:management-toolbar
		additionalProps="<%= redirectManagementToolbarDisplayContext.getAdditionalProps() %>"
		managementToolbarDisplayContext="<%= redirectManagementToolbarDisplayContext %>"
		propsTransformer="js/RedirectManagementToolbarPropsTransformer"
	/>
</c:if>

<div class="closed redirect-entries sidenav-container sidenav-right" id="<%= liferayPortletResponse.getNamespace() + "infoPanelId" %>">
	<liferay-portlet:resourceURL copyCurrentRenderParameters="<%= false %>" id="/redirect/info_panel" var="sidebarPanelURL" />

	<liferay-frontend:sidebar-panel
		resourceURL="<%= sidebarPanelURL %>"
		searchContainerId="<%= redirectDisplayContext.getSearchContainerId() %>"
	>
		<liferay-util:include page="/info_panel.jsp" servletContext="<%= application %>" />
	</liferay-frontend:sidebar-panel>

	<div class="sidenav-content">
		<clay:container-fluid>
			<c:if test="<%= stagingGroup %>">
				<div class="lfr-search-container">
					<clay:alert
						displayType="info"
						message="redirections-are-unavailable-in-staged-sites"
					/>
				</div>
			</c:if>

			<aui:form action="<%= redirectSearchContainer.getIteratorURL() %>" cssClass="container-fluid container-fluid-max-xl" name="fm">
				<aui:input name="redirect" type="hidden" value="<%= currentURL %>" />

				<liferay-ui:search-container
					id="<%= redirectDisplayContext.getSearchContainerId() %>"
					searchContainer="<%= redirectSearchContainer %>"
				>
					<liferay-ui:search-container-row
						className="com.liferay.redirect.model.RedirectEntry"
						keyProperty="redirectEntryId"
						modelVar="redirectEntry"
					>

						<%
						row.setData(
							HashMapBuilder.<String, Object>put(
								"actions", redirectManagementToolbarDisplayContext.getAvailableActions(redirectEntry)
							).build());
						%>

						<liferay-ui:search-container-column-text
							cssClass="table-cell-expand table-cell-text-truncate-reverse"
							name="source-url"
						>

							<%
							String sourceURL = HtmlUtil.escape(RedirectUtil.getGroupBaseURL(themeDisplay) + StringPool.SLASH + redirectEntry.getSourceURL());
							%>

							<bdi data-title="<%= HtmlUtil.escapeAttribute(sourceURL) %>">
								<%= sourceURL %>
							</bdi>
						</liferay-ui:search-container-column-text>

						<liferay-ui:search-container-column-text
							cssClass="table-cell-expand table-cell-text-truncate-reverse"
							name="destination-url"
						>

							<%
							String destinationURL = HtmlUtil.escape(redirectEntry.getDestinationURL());
							%>

							<bdi data-title="<%= HtmlUtil.escapeAttribute(destinationURL) %>">
								<%= destinationURL %>
							</bdi>
						</liferay-ui:search-container-column-text>

						<liferay-ui:search-container-column-text
							cssClass="table-cell-expand-smallest"
							name="type"
						>
							<liferay-ui:message key='<%= redirectEntry.isPermanent() ? "permanent" : "temporary" %>' />
						</liferay-ui:search-container-column-text>

						<liferay-ui:search-container-column-text
							cssClass="table-cell-expand-smallest"
							name="expiration"
						>
							<c:choose>
								<c:when test="<%= Validator.isNull(redirectEntry.getExpirationDate()) %>">
									<%= StringPool.DASH %>
								</c:when>
								<c:when test="<%= DateUtil.compareTo(redirectEntry.getExpirationDate(), DateUtil.newDate()) <= 0 %>">
									<strong><liferay-ui:message key="expired" /></strong>
								</c:when>
								<c:otherwise>
									<%= redirectDisplayContext.formatExpirationDate(redirectEntry.getExpirationDate()) %>
								</c:otherwise>
							</c:choose>
						</liferay-ui:search-container-column-text>

						<%
						List<DropdownItem> dropdownItems = redirectDisplayContext.getActionDropdownItems(redirectEntry);
						%>

						<c:if test="<%= ListUtil.isNotEmpty(dropdownItems) %>">
							<liferay-ui:search-container-column-text>
								<clay:dropdown-actions
									dropdownItems="<%= dropdownItems %>"
								/>
							</liferay-ui:search-container-column-text>
						</c:if>
					</liferay-ui:search-container-row>

					<liferay-ui:search-iterator
						markupView="lexicon"
						searchContainer="<%= redirectSearchContainer %>"
					/>
				</liferay-ui:search-container>
			</aui:form>
		</clay:container-fluid>
	</div>
</div>

<aui:script require="frontend-js-web/liferay/delegate/delegate.es as delegateModule">
	var delegate = delegateModule.default;

	delegate(
		document.querySelector('#<portlet:namespace />fm'),
		'click',
		'.icon-shortcut',
		(event) => {
			var delegateTarget = event.delegateTarget;

			var destinationURL = delegateTarget.dataset.href;

			if (destinationURL) {
				window.open(destinationURL, '_blank');
			}
		}
	);
</aui:script>